How to Read this Manual - SQLAlchemy Documentation

How to Read this Manual
Version: 0.1.6 Last Updated: 04/12/06 12:42:40

SQLAlchemy features a lot of tools and patterns to help in every area of writing applications that talk to relational databases. To achieve this, it has a lot of areas of functionality which work together to provide a cohesive package. Ultimately, just a little bit of familiarity with each concept is all that's needed to get off the ground.

That said, here's two quick links that summarize the two most prominent features of SQLAlchemy:

- None - a synopsis of how to map objects to database tables (Object Relational Mapping)
- None - SQLAlchemy's own domain-oriented approach to constructing and executing SQL statements.

Trail Map

For a comprehensive tour through all of SQLAlchemy's components, below is a "Trail Map" of the knowledge dependencies between these components indicating the order in which concepts may be learned. Concepts marked in bold indicate features that are useful on their own.

    Start
      |
      |
      |--- Connection Pooling
      |              |
      |              |
      |              |------ Connection Pool Configuration
      |                                         |
      |                                         |
      +--- Establishing a Database Engine       |
                       |                        |
                       |                        |
                       |--------- Database Engine Options
                       |
                       |
                       +---- Describing Tables with MetaData
                                       |
                                       |
                                       |---- Creating and Dropping Database Tables
                                       |
                                       |
                                       |---- None
                                       |                                      |
                                       |                                      |
                                       +---- None               |
                                       |               |                      |
                                       |               |                      |
                                       |         None                 |
                                       |               |                      |
                                       |               |                      |
                                       |               +----------- Advanced Data Mapping
                                       |
                                       +----- The Types System

back to section top
Next: Connection Pooling